import { AfterViewInit, ElementRef, OnDestroy } from '@angular/core';
import { ControlValueAccessor, NgControl } from '@angular/forms';
import { MatFormFieldControl } from '@angular/material/form-field';
import { Subject } from 'rxjs';
import { EditorComponent } from '../editor';
import { FocusMonitor } from '@angular/cdk/a11y';
import { FormatterService } from '../../services/formatter.service';
import { ParseResult } from '../../models/templates/parse-result';
import { ModeType } from '../../format-rules';
import { NgxExpressionsConfig } from '../../models';
export declare const SINGLE_LINE_HEIGHT_PX = 22;
export declare const MAX_VISIBLE_LINE_COUNT = 8;
export declare class InputComponent implements AfterViewInit, ControlValueAccessor, MatFormFieldControl<string>, OnDestroy {
    protected config: NgxExpressionsConfig;
    protected focusMonitor: FocusMonitor;
    protected elementRef: ElementRef<HTMLElement>;
    ngControl: NgControl;
    protected formatter: FormatterService;
    get busy(): boolean;
    get returnType(): string;
    set returnType(value: 'string' | 'number' | 'Date' | 'boolean' | 'any' | string);
    get disabled(): boolean;
    set disabled(value: boolean);
    get placeholder(): string;
    set placeholder(value: string);
    get autosize(): boolean;
    set autosize(value: boolean);
    get required(): boolean;
    set required(value: boolean);
    get value(): string;
    set value(value: string);
    get shouldLabelFloat(): boolean;
    get validationErrors(): string[];
    get styles(): any;
    get scrolling(): boolean;
    get empty(): boolean;
    get errorState(): boolean;
    get focused(): boolean;
    set focused(value: boolean);
    constructor(config: NgxExpressionsConfig, focusMonitor: FocusMonitor, elementRef: ElementRef<HTMLElement>, ngControl: NgControl, formatter: FormatterService);
    static nextId: number;
    editorRef: EditorComponent;
    language: string;
    color: 'primary' | 'accent';
    get parameters(): string;
    set parameters(value: string);
    get mode(): ModeType;
    set mode(value: ModeType);
    output: 'function' | 'template';
    describedBy: string;
    id: string;
    autofilled: boolean;
    controlType: string;
    stateChanges: Subject<void>;
    protected _parameters: string;
    protected _mode: ModeType;
    protected _returnType: 'string' | 'number' | 'Date' | 'boolean' | 'any' | string;
    protected _validations: string[];
    protected _onChange: (value: string) => void;
    protected _onTouched: () => void;
    protected _value: string;
    protected _parseResult: ParseResult;
    protected _busy: boolean;
    protected _disabled: boolean;
    protected _focused: boolean;
    protected _placeholder: string;
    protected _required: boolean;
    protected _destroy: Subject<void>;
    protected _autosize: boolean;
    updateLayout(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    onContainerClick(event: MouseEvent): void;
    onEditorReady(): Promise<void>;
    registerOnChange(onChange: (value: string) => void): void;
    registerOnTouched(onTouched: () => void): void;
    setDescribedByIds(ids: string[]): void;
    setDisabledState(shouldDisable: boolean): void;
    writeValue(value: string): void;
    protected onTouched(): void;
    protected onChange(value: string): void;
    protected applyValue(): void;
    protected addListeners(): void;
    protected reloadParseResult(): ParseResult;
    protected getParseResult(): ParseResult;
    protected updateHiddenRanges(): void;
    protected getTargetCode(): string;
}
